# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2025/07/15 15:34
@Description: Description
@File: administrator_service.py
"""
from typing import List

from api_requester.core.admin.api.administrator_api import AdministratorApi
from api_requester.core.admin.dto.administrator import Administrator
from api_requester.core.admin.dto.administrator_query_dto import AdministratorQueryDto
from api_requester.core.admin.dto.change_password_dto import ChangePasswordDto
from api_requester.core.admin.dto.change_user_password import ChangeUserPassword
from api_requester.core.admin.dto.jwt_authentication_request import JwtAuthenticationRequest
from api_requester.core.admin.dto.sso_token_retrieve_dto import SsoTokenRetrieveDto


class AdministratorService(AdministratorApi):
    """
    The AdministratorService was generated by Generator from the AdministratorController.java file.
    """

    def __init__(self):
        AdministratorApi.__init__(self)
    
    def administrator_authentication_token(self, authentication_request: JwtAuthenticationRequest = None):
        return self.administrator_authentication_token_api(json=authentication_request)
    
    def change_administrator_password(self, change_password_dto: ChangePasswordDto = None):
        return self.change_administrator_password_api(json=change_password_dto)
    
    def administrator_list(self, page_no: int = 1, page_size: int = 10, administrator_query_dto: AdministratorQueryDto = None):
        return self.administrator_list_api(params=dict(pageNo=page_no, pageSize=page_size), json=administrator_query_dto)
    
    def create_administrator(self, administrator: Administrator = None):
        return self.create_administrator_api(json=administrator)
    
    def delete_administrator(self, administrator_id: int):
        return self.delete_administrator_api(url_kwargs={'administrator-id': administrator_id})
    
    def update_administrator(self, administrator_id: int, administrator: Administrator = None):
        return self.update_administrator_api(url_kwargs={'administrator-id': administrator_id}, json=administrator)
    
    def update_administrator_password(self, administrator_id: int, change_user_password: ChangeUserPassword = None):
        return self.update_administrator_password_api(url_kwargs={'administrator-id': administrator_id}, json=change_user_password)
    
    def administrator_administrator_id_user_activation(self, administrator_id: int, administrator: Administrator = None):
        return self.administrator_administrator_id_user_activation_api(url_kwargs={'administrator-id': administrator_id}, json=administrator)
    
    def administrator_permission(self):
        return self.administrator_permission_api()
    
    def set_administrator_permission(self, administrator_id: int, permission_id: List[int] = None):
        return self.set_administrator_permission_api(url_kwargs={'administrator-id': administrator_id}, json=permission_id)
    
    def get_administrator_permission(self, administrator_id: int):
        return self.get_administrator_permission_api(url_kwargs={'administrator-id': administrator_id})
    
    def init_business_log_table(self, system_ids: str = None):
        return self.init_business_log_table_api(params=dict(systemIds=system_ids))
    
    def alter_business_log_table(self, system_ids: str = None):
        return self.alter_business_log_table_api(params=dict(systemIds=system_ids))
    
    def count_permissions(self, include_facade: bool = False, system_ids: str = None):
        return self.count_permissions_api(params=dict(includeFacade=include_facade, systemIds=system_ids))
    
    def execute_upload_sql(self, env: str = None, password: str = None, schema_type: int = None, sponsor_id: int = None, study_id: int = None, system_id: int = None, file=None):
        return self.execute_upload_sql_api(params=dict(env=env, password=password, schemaType=schema_type, sponsorId=sponsor_id, studyId=study_id, systemId=system_id), multipart_encoder_kwargs=dict(file=file))
    
    def clean_release_package(self, password: str = None, release_package_name: str = None):
        return self.clean_release_package_api(params=dict(password=password, releasePackageName=release_package_name))
    
    def execute_upload_sql_in_portal(self, password: str = None, file=None):
        return self.execute_upload_sql_in_portal_api(params=dict(password=password), multipart_encoder_kwargs=dict(file=file))
    
    def execute_complex_sql_in_portal(self, password: str = None, file=None):
        return self.execute_complex_sql_in_portal_api(params=dict(password=password), multipart_encoder_kwargs=dict(file=file))
    
    def change_my_password(self, change_user_password: ChangeUserPassword = None):
        return self.change_my_password_api(json=change_user_password)
    
    def administrator_auth_sso_token(self, token_retrieve: SsoTokenRetrieveDto = None):
        return self.administrator_auth_sso_token_api(json=token_retrieve)
    


# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2025/05/15 09:04
@Description: Description
@File: administrator.py
"""
from dataclasses import dataclass
from datetime import datetime

from api_requester.dto.base_dto import BaseDto


@dataclass
class Administrator(BaseDto):
    """
    The Administrator was generated by Generator from the Administrator.java file.
    """
    id: int = None
    loginName: str = None
    password: str = None
    active: bool = None
    firstName: str = None
    lastName: str = None
    creatorDt: datetime = None
    modifyDt: datetime = None
    creatorUid: str = None
    modifyUid: str = None
    isDelete: bool = None
    superAdmin: bool = None
    email: str = None
    ssoExternalId: str = None
    serialVersionUID: int = 1



# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2025/05/15 09:04
@Description: Description
@File: administrator_api.py
"""
from api_requester.http.eclinical_requests import *


class AdministratorApi:
    """
    The AdministratorApi was generated by Generator from the AdministratorController.java file.
    """

    @post('/administrator/auth')
    def administrator_authentication_token_api(self, *args, **kwargs): ...

    @put('/administrator/password')
    def change_administrator_password_api(self, *args, **kwargs): ...

    @post('/administrator/user-list')
    def administrator_list_api(self, *args, **kwargs): ...

    @post('/administrator/user')
    def create_administrator_api(self, *args, **kwargs): ...

    @delete('/administrator/{administrator-id}/user')
    def delete_administrator_api(self, *args, **kwargs): ...

    @put('/administrator/{administrator-id}/user')
    def update_administrator_api(self, *args, **kwargs): ...

    @put('/administrator/{administrator-id}/user/change-password')
    def update_administrator_password_api(self, *args, **kwargs): ...

    @put('/administrator/{administrator-id}/user/activation')
    def administrator_administrator_id_user_activation_api(self, *args, **kwargs): ...

    @get('/administrator/permission')
    def administrator_permission_api(self, *args, **kwargs): ...

    @put('/administrator/{administrator-id}/permission')
    def set_administrator_permission_api(self, *args, **kwargs): ...

    @get('/administrator/{administrator-id}/permission')
    def get_administrator_permission_api(self, *args, **kwargs): ...

    @get('/initBusinessLogTable')
    def init_business_log_table_api(self, *args, **kwargs): ...

    @get('/alterBusinessLogTable')
    def alter_business_log_table_api(self, *args, **kwargs): ...

    @get('/count/permissions')
    def count_permissions_api(self, *args, **kwargs): ...

    @post('/execute-upload-sql/')
    def execute_upload_sql_api(self, *args, **kwargs): ...

    @post('/clean-release-package/')
    def clean_release_package_api(self, *args, **kwargs): ...

    @post('/execute-sql-in-portal/')
    def execute_upload_sql_in_portal_api(self, *args, **kwargs): ...

    @post('/execute-complex-sql-in-portal/')
    def execute_complex_sql_in_portal_api(self, *args, **kwargs): ...

    @post('/administrator/user/change-my-password')
    def change_my_password_api(self, *args, **kwargs): ...

    @post('/administrator/auth/sso/token')
    def administrator_auth_sso_token_api(self, *args, **kwargs): ...



# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2024/04/26 16:09
@Description: Description
@File: change_user_password.py
"""
from dataclasses import dataclass

from api_requester.dto.base_dto import BaseDto


@dataclass
class ChangeUserPassword(BaseDto):
    """
    The ChangeUserPassword was generated by Generator from the ChangeUserPassword.java file.
    """
    userId: int = None
    newPassword: str = None
    oldPassword: str = None



# !/usr/bin/python3
# -*- coding:utf-8 -*-
"""
@Author: xiaodong.li
@Time: 2025/05/15 09:04
@Description: Description
@File: administrator_query_dto.py
"""
from dataclasses import dataclass

from api_requester.dto.base_dto import BaseDto


@dataclass
class AdministratorQueryDto(BaseDto):
    """
    The AdministratorQueryDto was generated by Generator from the AdministratorQueryDto.java file.
    """
    loginName: str = None
    firstName: str = None
    lastName: str = None
    email: str = None
    superAdmin: bool = None
    active: bool = None
